@@ -2,8 +2,8 @@ import itertools
 from contextlib import ExitStack
 from typing import Iterator, Mapping, MutableSet, Optional, Tuple, Union, cast
 
-from afancontrol.config import AnyFanName, FanName, ReadonlyFanName
 from afancontrol.logger import logger
+from afancontrol.pwmfan import AnyFanName, FanName, ReadonlyFanName
 from afancontrol.pwmfannorm import PWMFanNorm, PWMValueNorm, ReadonlyPWMFanNorm
 from afancontrol.report import Report
 
@@ -19,13 +19,13 @@ class Fans:
         self.fans = fans
         self.readonly_fans = readonly_fans
         self.report = report
-        self._stack = None  # type: Optional[ExitStack]
+        self._stack: Optional[ExitStack] = None
 
         # Set of fans marked as failing (which speed is 0)
-        self._failed_fans = set()  # type: MutableSet[AnyFanName]
+        self._failed_fans: MutableSet[AnyFanName] = set()
 
         # Set of fans that will be skipped on speed check
-        self._stopped_fans = set()  # type: MutableSet[AnyFanName]
+        self._stopped_fans: MutableSet[AnyFanName] = set()
 
     def is_fan_failing(self, fan_name: AnyFanName) -> bool:
         return fan_name in self._failed_fans
